@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------*/
-/*     Copyright (C) 2004-2015  Serge Iovleff, Université Lille 1, Inria
+/*     Copyright (C) 2004-2016  Serge Iovleff, Université Lille 1, Inria
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as
@@ -77,6 +77,9 @@ class ArrayBase :  public ExprBase<Derived>
       storage_   = hidden::Traits<Derived>::storage_
     };
 
+    /** iterator class for compatibility with the stl */
+    class iterator;
+
   protected:
     /** Default constructor. Default values are cols=(1:0) and rows=(1:0). */
     ArrayBase() : Base() {}
