@@ -132,25 +132,25 @@ class ChiSquared : public IUnivLaw<Real>
 
 /* @return a pseudo ChiSquared random variate. */
 inline Real ChiSquared::rand() const
-{ GetRNGstate(); Real s = ::Rf_rchisq(df_);
+{ GetRNGstate(); Real s = Rf_rchisq(df_);
   PutRNGstate(); return s;
 }
 /* @return the value of the pdf
  *  @param x a positive real value
  **/
-inline Real ChiSquared::pdf(const Real& x) const { return ::Rf_dchisq(x, df_, false);}
-inline Real ChiSquared::lpdf(const Real& x) const { return ::Rf_dchisq(x, df_, true);}
-inline Real ChiSquared::cdf(const Real& t) const { return ::Rf_pchisq(t, df_, true, false);}
-inline Real ChiSquared::icdf(const Real& p) const { return ::Rf_qchisq(p, df_, true, false);}
+inline Real ChiSquared::pdf(const Real& x) const { return Rf_dchisq(x, df_, false);}
+inline Real ChiSquared::lpdf(const Real& x) const { return Rf_dchisq(x, df_, true);}
+inline Real ChiSquared::cdf(const Real& t) const { return Rf_pchisq(t, df_, true, false);}
+inline Real ChiSquared::icdf(const Real& p) const { return Rf_qchisq(p, df_, true, false);}
 
 inline Real ChiSquared::rand(int df)
-{ GetRNGstate(); Real s = ::Rf_rchisq(df);
+{ GetRNGstate(); Real s = Rf_rchisq(df);
   PutRNGstate(); return s;
 }
-inline Real ChiSquared::pdf(const Real& x, int df) { return ::Rf_dchisq(x, df, false);}
-inline Real ChiSquared::lpdf(const Real& x, int df) { return ::Rf_dchisq(x, df, true);}
-inline Real ChiSquared::cdf(const Real& t, int df) { return ::Rf_pchisq(t, df, true, false);}
-inline Real ChiSquared::icdf(const Real& p, int df) { return ::Rf_qchisq(p, df, true, false);}
+inline Real ChiSquared::pdf(const Real& x, int df) { return Rf_dchisq(x, df, false);}
+inline Real ChiSquared::lpdf(const Real& x, int df) { return Rf_dchisq(x, df, true);}
+inline Real ChiSquared::cdf(const Real& t, int df) { return Rf_pchisq(t, df, true, false);}
+inline Real ChiSquared::icdf(const Real& p, int df) { return Rf_qchisq(p, df, true, false);}
 
 #endif
 
