@@ -163,9 +163,9 @@ inline int Poisson::rand() const
 { GetRNGstate(); int s = (int)::Rf_rpois(lambda_);
   PutRNGstate(); return s;
 }
-inline Real Poisson::pdf(int const& x) const { return ::Rf_dpois((double)x, lambda_, false);}
-inline Real Poisson::lpdf(int const& x) const { return ::Rf_dpois((double)x, lambda_, true);}
-inline Real Poisson::cdf(Real const& t) const { return ::Rf_ppois(t, lambda_, true, false);}
+inline Real Poisson::pdf(int const& x) const { return Rf_dpois((double)x, lambda_, false);}
+inline Real Poisson::lpdf(int const& x) const { return Rf_dpois((double)x, lambda_, true);}
+inline Real Poisson::cdf(Real const& t) const { return Rf_ppois(t, lambda_, true, false);}
 inline int Poisson::icdf(Real const& p) const { return (int)::Rf_qpois(p, lambda_, true, false);}
 
 /* static */
@@ -174,11 +174,11 @@ inline int Poisson::rand(Real const& lambda)
   PutRNGstate(); return s;
 }
 inline Real Poisson::pdf(int const& x, Real const& lambda)
-{ return ::Rf_dpois((double)x, lambda, false);}
+{ return Rf_dpois((double)x, lambda, false);}
 inline Real Poisson::lpdf(int const& x, Real const& lambda)
-{ return ::Rf_dpois((double)x, lambda, true);}
+{ return Rf_dpois((double)x, lambda, true);}
 inline Real Poisson::cdf(Real const& t, Real const& lambda)
-{ return ::Rf_ppois(t, lambda, true, false);}
+{ return Rf_ppois(t, lambda, true, false);}
 inline int Poisson::icdf(Real const& p, Real const& lambda)
 { return (int)::Rf_qpois(p, lambda, true, false);}
 
